@@ -1,13 +1,8 @@
 package Hailo::Engine::Default;
-BEGIN {
-  $Hailo::Engine::Default::AUTHORITY = 'cpan:AVAR';
-}
-{
-  $Hailo::Engine::Default::VERSION = '0.72';
-}
-
-use 5.010;
-use Any::Moose;
+our $AUTHORITY = 'cpan:AVAR';
+$Hailo::Engine::Default::VERSION = '0.73';
+use v5.28.0;
+use Moose;
 use List::Util qw<min first shuffle>;
 use List::MoreUtils qw<uniq>;
 
