@@ -1,13 +1,8 @@
 package Hailo::Role::Tokenizer;
-BEGIN {
-  $Hailo::Role::Tokenizer::AUTHORITY = 'cpan:AVAR';
-}
-{
-  $Hailo::Role::Tokenizer::VERSION = '0.72';
-}
-
-use 5.010;
-use Any::Moose '::Role';
+our $AUTHORITY = 'cpan:AVAR';
+$Hailo::Role::Tokenizer::VERSION = '0.73';
+use v5.28.0;
+use Moose::Role;
 use namespace::clean -except => 'meta';
 
 has spacing => (
