@@ -1,6 +1,6 @@
 package Hailo::Test::Tokenizer;
-use 5.010;
-use Any::Moose;
+use v5.28.0;
+use Moose;
 use namespace::clean -except => 'meta';
 use Hailo::Tokenizer::Words;
 
